@@ -2,6 +2,7 @@
 
 import os
 import tempfile
+import argparse 
 import numpy as np
 import sqlite3
 import time 
@@ -12,7 +13,33 @@ from dask.delayed import delayed
 import copy
 import sys
 import datetime
-from radvelso.fill_ray import fill_ray_dict
+import radvelso
+
+
+def find_schema(schema_name):
+  """find schema file contained in the Python package
+
+   args: 
+     schema_name : name of the schema we are looking for
+
+   output:
+     full path of schema file that was found
+  """
+
+  #full path of radvelso module
+  radvelso_dir = os.path.dirname(radvelso.__file__)
+  #root path of radvelso package (one dir up from radvelso module)
+  package_dir = os.path.dirname(radvelso_dir)
+  #full path of schema we are looking for
+  schema_file = f'{package_dir}/schemas/{schema_name}'
+
+  if not os.path.isfile(schema_file):
+    raise ValueError(f'schema_file: {schema_file} does not exist')
+
+  return schema_file
+
+
+
 def make_input_ppi_db(filein, 
                       stn, 
                       this_time, 
@@ -47,7 +74,8 @@ def make_input_ppi_db(filein,
   # SQLite continues without syncing as soon as it has handed data off to the operating system
   conn_ppi_db.execute("""PRAGMA synchronous=OFF;""")
 
-  with open('schema_ppi') as f:
+  schema_ppi = find_schema('schema_ppi')
+  with open(schema_ppi) as f:
     schema = f.read()
   conn_ppi_db.executescript(schema)
   conn_ppi_db.execute("ATTACH DATABASE ? AS db_all", (filein,)) 
@@ -380,7 +408,8 @@ def superobs(filein,
   # SQLite continues without syncing as soon as it has handed data off to the operating system
   conn_filememory.execute("""PRAGMA synchronous=OFF;""")
 
-  with open('schema_memory') as f:
+  schema_memory = find_schema('schema_memory')
+  with open(schema_memory) as f:
     schema = f.read( )
   conn_filememory.executescript(schema)
 
@@ -551,130 +580,24 @@ def distinct_id_obs(conn_pathfileout):
    if (distinct_id_obs_from_header !=  distinct_id_obs_from_data): 
       raise RuntimeError("""Error: id_obs is not associated properly""")
 
-def main(center_time,
-         window_width,
-         infile_list, 
-         pathout, 
-         outfile_struc, 
-         timing, 
-         ops_run_name, 
-         n_rays, 
-         delta_range,
-         n_cpus):
-  """launch computation of average volums scans, possibly in parallel
+def superobs_sqlite():
+
+  """Compute average volume scans, possibly in parallel
 
   args:
-    center_time  : datetime object,  center time of the assimilation window
-    window_width : [hours] Width of the assimilation window
-    infile_list  : list of input files to be superobbed
-    pathout      : output average sqlite file(s) 
-    outfile_struc: structure of output file name ; will be passed to strftime
-    timing       : activation of time analysis, only the first PPI in a volume scan will be averaged
-    ops_run_name : name of operational run 
-    n_rays       : number of rays
-    delta_range  : delta range of the boxes
-    n_cpus       : number of cpus for parallel execution, with n_cpus=1 joba are launched sequentially and dask is not invoked 
- 
+    see argparse definitions just below for command line arguments to this function
+
   output:
     Nothing
     Average sqlite file(s) are created with the '_thin' suffix
 
   """
 
-  #start and stop time of assimilation window
-  window_t0 = center_time - datetime.timedelta(seconds=3600*window_width/2.)
-  window_tf = center_time + datetime.timedelta(seconds=3600*window_width/2.)
-  
-  #flush fileout if it already exists
-  pathfileout=f"{pathout}/{center_time.strftime(outfile_struc)}"
-
-  if os.path.isfile(pathfileout):
-    os.remove(pathfileout)
-
-  #init large output file
-  conn_pathfileout = sqlite3.connect(pathfileout)
-  with open('schema_sqlmidas') as f:
-    schema = f.read()
-  conn_pathfileout.executescript(schema)
-
-  # make list of files, radars and times that will be processed in parallel
-  vol_scan_list = []
-  for this_file in infile_list:
-    with sqlite3.connect(this_file) as conn_loops:
-      # list of radars in the file
-      radar_list  = [ stn[0] for stn in conn_loops.execute("select distinct ID_STN from header order by 1;").fetchall() ]
-
-      for this_radar in radar_list:
-        # dates
-        result = conn_loops.execute(f"select distinct DATE, printf('%06d', TIME) from header where ID_STN = '{this_radar}' ;").fetchall()
-        datetime_list  = [datetime.datetime.strptime(f'{date_time[0]}{date_time[1]}', '%Y%m%d%H%M%S') for date_time in result]
-        datetime_list.sort()
-
-        for this_date in datetime_list:
-          #only include date in assimilation window
-          if (this_date > window_t0) and (this_date <= window_tf):
-            vol_scan_list.append( {'file':this_file, 'radar':this_radar, 'date':this_date} )
-
-  #initialize template that will be used for averaging every PPIs
-  min_range_in_ppi =  10000.
-  max_range_in_ppi = 240000.
-  averaging_template = fill_ray_dict(n_rays=n_rays,
-                                     min_range_in_ppi = min_range_in_ppi,
-                                     max_range_in_ppi = max_range_in_ppi,
-                                     delta_range= delta_range)
-  
-  tc_0 = time.time()
-  if timing :
-
-    print ("Compute only one PPI ")
-    this_file  = vol_scan_list[0]['file']
-    this_radar = vol_scan_list[0]['radar']
-    this_date  = vol_scan_list[0]['date']
-    superobs(this_file, this_radar, this_date, 
-             pathfileout, averaging_template, ops_run_name, timer=True)
-    tc_1 = time.time()
-
-  else:
-
-    if n_cpus == 1:
-      #serial execution, usefull for debugging
-      print('Serial execution')
-      for vscan in vol_scan_list:
-        superobs(vscan['file'] ,vscan['radar'], vscan['date'], 
-                 pathfileout, averaging_template, ops_run_name)
-    else:
-      print('Compute volume scans in parallel')
-      with tempfile.TemporaryDirectory() as tmpdir:
-        #the directory dask-worker-space/ will be in tmpdir
-        with dask.distributed.Client(processes=True, threads_per_worker=1, 
-                                   n_workers=n_cpus, 
-                                   local_directory=tmpdir, 
-                                   silence_logs=40) as client:
-
-          #delay data 
-          averaging_template = dask.delayed(averaging_template)
-          joblist = [delayed(superobs)(vscan['file'], vscan['radar'], vscan['date'], 
-                                       pathfileout, averaging_template, ops_run_name) for vscan in vol_scan_list]
-          dask.compute(joblist)
-   
-    sample_file  = vol_scan_list[0]['file']
-    # create info and resume_tables in fileout
-    create_info_resume_tables(sample_file, conn_pathfileout, n_rays, delta_range, ops_run_name)   
-    # test id_obs 
-    distinct_id_obs(conn_pathfileout)
-    # close connection
-    conn_pathfileout.close()
-    tc_1 = time.time()
-   
-  print(f"Runtime total: {round(tc_1-tc_0,4)} s")
-
-if __name__ == '__main__':
-
-  import argparse 
 
   parser = argparse.ArgumentParser()
   parser.add_argument('--center_time',  default='undefined', type=str,   help="YYYYMMDDHH center time of assimilation window")
   parser.add_argument('--window_width', default=0.,          type=float, help="[hours] width of assimilation window")
+  parser.add_argument('--radar_list', nargs="+", default='all',          help="List of radars to process")
   parser.add_argument('--inputfiles', nargs="+", default='undefined',    help="input sqlite file to average")
   parser.add_argument('--pathin',       default='undefined', type=str,   help="directory where are input sqlite files")
   parser.add_argument('--infile_struc', default='*/%Y%m%d%H_ra',type=str,help="structure of input file name")
@@ -688,10 +611,15 @@ if __name__ == '__main__':
 
   args = parser.parse_args()
 
+
+  #run demo case when input files unspecified
   if args.inputfiles == 'undefined' and args.pathin == 'undefined':
 
+    print(f'superobs called with no input filename(s)')
+
     args.center_time = '2019073100'
     args.window_width = 6.
+    args.radar_list = ['casra', 'usdyx']
     #option1: explicitely specify inputfiles
     #args.inputfiles = ['/space/hall4/sitestore/eccc/cmd/a/dlo001/data/doppler_qc/doppler_qc_v0.3/sqlite_v1.0.0_qc/split_6h/USVNX/2019073100_ra',
     #                   '/space/hall4/sitestore/eccc/cmd/a/dlo001/data/doppler_qc/doppler_qc_v0.3/sqlite_v1.0.0_qc/split_6h/CASRA/2019073100_ra']
@@ -702,10 +630,10 @@ if __name__ == '__main__':
     args.plot   = False
     args.n_cpus = 40
 
-    print(f'superobs called with no input filename(s)')
-    print(f'We are running demo with:')
-    for arg in vars(args):
-      print(f'--{arg}  {getattr(args, arg)}')
+
+  print(f'superobs_sqlite starting with the following arguments:')
+  for arg in vars(args):
+    print(f'--{arg}  {getattr(args, arg)}')
 
 
   #argument checking
@@ -744,15 +672,119 @@ if __name__ == '__main__':
   if not os.path.isdir(args.pathout):
     os.mkdir(args.pathout)
 
+  center_time        = args.center_time
+  window_width       = args.window_width
+  desired_radar_list = args.radar_list
+  pathout            = args.pathout
+  outfile_struc      = args.outfile_struc
+  timing             = args.timing
+  ops_run_name       = args.ops_run_name
+  n_rays             = args.n_rays
+  delta_range        = args.delta_range
+  n_cpus             = args.n_cpus        
+
+  #we are done processing arguments
+
+
+
+  #start and stop time of assimilation window
+  window_t0 = center_time - datetime.timedelta(seconds=3600*window_width/2.)
+  window_tf = center_time + datetime.timedelta(seconds=3600*window_width/2.)
+  
+  #flush fileout if it already exists
+  pathfileout=f"{pathout}/{center_time.strftime(outfile_struc)}"
+
+  if os.path.isfile(pathfileout):
+    os.remove(pathfileout)
+
+  #init large output file
+  conn_pathfileout = sqlite3.connect(pathfileout)
+
+  schema_sqlmidas = find_schema('schema_sqlmidas')
+  with open(schema_sqlmidas) as f:
+    schema = f.read()
+  conn_pathfileout.executescript(schema)
+
+  print('make list of files, radars and times that will be processed in parallel...')
+  vol_scan_list = []
+  for this_file in infile_list:
+    with sqlite3.connect(this_file) as conn_loops:
+      # list of radars in the file
+      avail_radar_list  = [ stn[0] for stn in conn_loops.execute("select distinct ID_STN from header order by 1;").fetchall() ]
+
+      for this_radar in avail_radar_list:
+        #select radars if desired radar_list is specified
+        if desired_radar_list != 'all':
+          if this_radar not in desired_radar_list:
+            continue
+        # dates
+        result = conn_loops.execute(f"select distinct DATE, printf('%06d', TIME) from header where ID_STN = '{this_radar}' ;").fetchall()
+        datetime_list  = [datetime.datetime.strptime(f'{date_time[0]}{date_time[1]}', '%Y%m%d%H%M%S') for date_time in result]
+        datetime_list.sort()
+
+        for this_date in datetime_list:
+          #only include date in assimilation window
+          if (this_date > window_t0) and (this_date <= window_tf):
+            vol_scan_list.append( {'file':this_file, 'radar':this_radar, 'date':this_date} )
+
+  if len(vol_scan_list) == 0:
+    raise RuntimeError('List of volume scan to process is empty. Check that files are available and search criteria are correct.')
+
+  print('make averaging template')
+  #initialize template that will be used for averaging every PPIs
+  min_range_in_ppi =  10000.
+  max_range_in_ppi = 240000.
+  averaging_template = radvelso.fill_ray_dict(n_rays=n_rays,
+                                              min_range_in_ppi = min_range_in_ppi,
+                                              max_range_in_ppi = max_range_in_ppi,
+                                              delta_range= delta_range)
+  
+  tc_0 = time.time()
+  if timing :
+
+    print ("Compute only one PPI ")
+    this_file  = vol_scan_list[0]['file']
+    this_radar = vol_scan_list[0]['radar']
+    this_date  = vol_scan_list[0]['date']
+    superobs(this_file, this_radar, this_date, 
+             pathfileout, averaging_template, ops_run_name, timer=True)
+    tc_1 = time.time()
+
+  else:
+
+    if n_cpus == 1:
+      #serial execution, usefull for debugging
+      print('Serial execution')
+      for vscan in vol_scan_list:
+        superobs(vscan['file'] ,vscan['radar'], vscan['date'], 
+                 pathfileout, averaging_template, ops_run_name)
+    else:
+      print(f'Compute {len(vol_scan_list)} volume scans in parallel')
+      with tempfile.TemporaryDirectory() as tmpdir:
+        #the directory dask-worker-space/ will be in tmpdir
+        with dask.distributed.Client(processes=True, threads_per_worker=1, 
+                                     n_workers=n_cpus, 
+                                     local_directory=tmpdir, 
+                                     silence_logs=40) as client:
+
+          #delay data 
+          averaging_template = dask.delayed(averaging_template)
+          joblist = [delayed(superobs)(vscan['file'], vscan['radar'], vscan['date'], 
+                                       pathfileout, averaging_template, ops_run_name) for vscan in vol_scan_list]
+          dask.compute(joblist)
+   
+    sample_file  = vol_scan_list[0]['file']
+    # create info and resume_tables in fileout
+    create_info_resume_tables(sample_file, conn_pathfileout, n_rays, delta_range, ops_run_name)   
+    # test id_obs 
+    distinct_id_obs(conn_pathfileout)
+    # close connection
+    conn_pathfileout.close()
+    tc_1 = time.time()
+   
+  print(f"Runtime total: {round(tc_1-tc_0,4)} s")
+
+if __name__ == '__main__':
   #sys.exit is used to the return status of main is catched and passed to caller
-  sys.exit(main(args.center_time,
-                args.window_width,
-                infile_list, 
-                args.pathout, 
-                args.outfile_struc, 
-                args.timing, 
-                args.ops_run_name, 
-                args.n_rays, 
-                args.delta_range, 
-                args.n_cpus) )
+  sys.exit( superobs_sqlite() )
 
